BasePageState<Widget extends StatefulWidget, Bloc extends BaseBloc> class abstract

Base config for StatefulWidget

Example use:

class AppPage extends StatefulWidget {
  const AppPage({super.key});

  @override
  State<AppPage> createState() => _AppPageState();
}

class _AppPageState extends BasePageState<AppPage, AppBloc> {
  @override
  Widget buildPage(BuildContext context) {
    return PageWidget();
  }
}
Inheritance
Mixed-in types

Constructors

BasePageState()

Properties

bloc → Bloc
This is Bloc get from GetIt
latefinalinherited
colorScheme ColorScheme
A set of 30 colors based on the Material spec that can be used to configure the color properties of most components.
getter/setter pairinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StatusState
Get status of page (Loading, success,..)
no setterinherited
textTheme TextTheme
Material design text theme.
getter/setter pairinherited
theme ThemeData
App design
getter/setter pairinherited
widget → Widget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildPage(BuildContext context) Widget
Build widget of page
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant Widget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
handleBuilder(BuildContext context, StatusState state) Widget
Build animation loading of page
inherited
handleBuildWhen(StatusState previous, StatusState current) bool
Takes the previous state and the current state and is responsible for returning a bool
inherited
handleListener(BuildContext context, StatusState state) → void
Takes the BuildContext along with the bloc state and is responsible for executing in response to state changes.
inherited
handleListenWhen(StatusState previous, StatusState current) bool
Takes the previous state and the current state and is responsible for returning a bool
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
logD(String message, {DateTime? time}) → void
Log data
inherited
logE(Object? errorMessage, {Object? errorObject, StackTrace? stackTrace, DateTime? time}) → void
Log error
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(void fn()) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited