BasePageStateDelegate<W extends StatefulWidget, B extends BaseBloc> class abstract

Delegate of BasePageState

Inheritance
Implementers

Constructors

BasePageStateDelegate()

Properties

bloc → B
This is Bloc get from GetIt
latefinal
context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StatusState
Get status of page (Loading, success,..)
no setter
widget → W
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildPage(BuildContext context) Widget
Build widget of page
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant W oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
handleBuilder(BuildContext context, StatusState state) Widget
Build animation loading of page
handleBuildWhen(StatusState previous, StatusState current) bool
Takes the previous state and the current state and is responsible for returning a bool
handleListener(BuildContext context, StatusState state) → void
Takes the BuildContext along with the bloc state and is responsible for executing in response to state changes.
handleListenWhen(StatusState previous, StatusState current) bool
Takes the previous state and the current state and is responsible for returning a bool
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited