handleBuildWhen method
Takes the previous state and the current state and is responsible for returning a bool
Implementation
@protected
bool handleBuildWhen(StatusState previous, StatusState current) => current != previous;
Takes the previous state and the current state and is responsible for returning a bool
@protected
bool handleBuildWhen(StatusState previous, StatusState current) => current != previous;