StatusCubit class

Status cubit of BaseBloc

Inheritance

Constructors

StatusCubit()
Creates a StatusCubit

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StatusState
The current state.
no setterinherited
stream Stream<StatusState>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(StatusState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
errorEmitted(Object error) → void
Change state to error
initalEmitted() → void
Change state to inital
loadingEmitted({bool useOverlay = true, double? progress}) → void
Change state to loading
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<StatusState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
runCubitCatching<T>({required Future<T> action(), FutureOr<void> doOnEventStart()?, FutureOr<void> doOnSuccess(T value)?, FutureOr<void> doOnError(Object error)?, FutureOr<void> doOnEventCompleted()?, bool autoHandleStatus = true}) Future<void>
Excute function safe
successEmitted() → void
Change state to success
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited