theme property
ThemeData
get
theme
A theme describes the colors and typographic choices of an application.
Implementation
ThemeData get theme => Theme.of(this);
A theme describes the colors and typographic choices of an application.
ThemeData get theme => Theme.of(this);