trimExtra method
Remove Leading and Trailing Spaces and remove Duplicate Spaces
Implementation
String? trimExtra() => this?.trim().replaceAll(RegExp(r"\s+"), " ");
Remove Leading and Trailing Spaces and remove Duplicate Spaces
String? trimExtra() => this?.trim().replaceAll(RegExp(r"\s+"), " ");