bold method
A commonly used font weight that is heavier than normal.
Implementation
TextStyle bold() => copyWith(fontWeight: FontWeight.bold);
A commonly used font weight that is heavier than normal.
TextStyle bold() => copyWith(fontWeight: FontWeight.bold);