DateTextFormatter class

TextInputFormatter for Date

Inheritance

Constructors

DateTextFormatter({String seperator = "-"})
Create a DateTextFormatter
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seperator String
Seperator for Date style
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateCursorPosition(String text) TextSelection
Move curso to end

Operators

operator ==(Object other) bool
The equality operator.
inherited