DateTimeFormatter class

Style format DateTime

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dateConvert DateFormat
Convert: yyyy-MM-dd
final
dateFormatDot DateFormat
Format: yyyy.MM.dd
final
dateFormatHyphen DateFormat
Format: yyyy-MM-dd
final
dateFormatSlash DateFormat
Format: yyyy/MM/dd
final
dateTimeConvert DateFormat
Convert: yyyy-MM-dd'T'HH:mm:ss.SSS'Z'
final
dateTimeFormatDot DateFormat
Format: yyyy.MM.dd HH:mm:ss
final
dateTimeFormatHyphen DateFormat
Format: yyyy-MM-dd HH:mm:ss
final
dateTimeFormatSlash DateFormat
Format: yyyy/MM/dd HH:mm:ss
final
l10nDateFormat DateFormat
Format: dd/MM/yyyy
final
l10nDateTimeFormat DateFormat
Format: dd/MM/yyyy HH:mm:ss
final
l10nDateTimeNoSecondFormat DateFormat
Format: dd/MM/yyyy HH:mm
final
l10nTimeFormat DateFormat
Format: HH:mm:ss
final
l10nTimeNoSecondFormat DateFormat
Format: HH:mm
final
timeFormat DateFormat
Format: HH:mm:ss
final
timeNoSecondFormat DateFormat
Format: HH:mm
final