NumberFormatter class

Style format number

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currency NumberFormat
Format: '#,##0.00 VND',
no setter
decimal NumberFormat
Format: '#,##0.###'
no setter
percent NumberFormat
Format: '#,##0%'
no setter
scientific NumberFormat
Format: '#E0'
no setter