LogUtil class

Until log data, error, ...

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enableLog bool
Enable log
getter/setter pair
isPrettyJson bool
Pretty json
getter/setter pair

Static Methods

d(Object? message, {String? name, DateTime? time}) → void
Log data
e(Object? errorMessage, {String? name, Object? errorObject, StackTrace? stackTrace, DateTime? time}) → void
Log error
log(String message, {int level = 0, String name = "LogUtil", DateTime? time, int? sequenceNumber, Zone? zone, Object? error, StackTrace? stackTrace}) → void
Emit a log event.
prettyJson(Object json) String
Log JSON pretty
recordError(Object error, StackTrace stack) → void
Log record error