util/util library

Classes

ConvertStringToDate
Convert field Date of Class to String of JSON
ConvertStringToDateTime
Convert field DateTime of Class to String of JSON
ConvertToBool
Convert field bool of Class to Object of JSON
ConvertToDouble
Convert field double of Class to Object of JSON
ConvertToInt
Convert field int of Class to Object of JSON
DateTextFormatter
TextInputFormatter for Date
DateTimeFormatter
Style format DateTime
DateTimeUtil
Until handle DateTime
LogUtil
Until log data, error, ...
NumberFormatter
Style format number
StringUtil
Until handle String