StatusCubit class
Status cubit of BaseBloc
- Inheritance
-
- Object
- BlocBase<
StatusState> - Cubit<
StatusState> - StatusCubit
Constructors
- StatusCubit()
- Creates a StatusCubit
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → StatusState
-
The current state.
no setterinherited
-
stream
→ Stream<
StatusState> -
The current stream of states.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggers onError with an optional StackTrace.inherited -
close(
) → Future< void> -
Closes the instance.
This method should be called when the instance is no longer needed.
Once close is called, the instance can no longer be used.
inherited
-
emit(
StatusState state) → void -
Updates the
stateto the providedstate. emit does nothing if thestatebeing emitted is equal to the currentstate.inherited -
errorEmitted(
Object error) → void - Change state to error
-
initalEmitted(
) → void - Change state to inital
-
loadingEmitted(
{bool useOverlay = true, double? progress}) → void - Change state to loading
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< StatusState> change) → void -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted. onChange is called before thestateof thecubitis updated. onChange is a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifies BlocObserver.onError.inherited -
runCubitCatching<
T> ({required Future< T> action(), FutureOr<void> doOnEventStart()?, FutureOr<void> doOnSuccess(T value)?, FutureOr<void> doOnError(Object error)?, FutureOr<void> doOnEventCompleted()?, bool autoHandleStatus = true}) → Future<void> - Excute function safe
-
successEmitted(
) → void - Change state to success
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited