DateTimeUtil class
Until handle DateTime
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertToDate(
DateTime dateTime) → String - Return a string representing format: yyyy-MM-dd
-
convertToDateRelative(
BuildContext context, DateTime dateTime, {Duration? formatAfter, Duration? timeShowNow = const Duration(seconds: 10)}) → String - Return a string representing format: Now, few Seconds Ago, 1 minutes ago, 2 hours ago, 3 days ago,...
-
convertToDateTime(
DateTime dateTime) → String - Return a string representing format: yyyy-MM-dd HH:mm:ss
-
convertToDateTimeNoSecond(
DateTime dateTime) → String - Return a string representing format: yyyy-MM-dd HH:mm
-
convertToTime(
DateTime dateTime) → String - Return a string representing format: HH:mm:ss
-
convertToTimeNoSecond(
DateTime dateTime) → String - Return a string representing format: HH:mm